==> cfn_lint-1.2.5a9.tar.gz: cfn_lint-1.2.5a9/test/unit/rules/resources/certificatemanager/test_domainvalidationoptions.py <==
"""
Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
SPDX-License-Identifier: MIT-0
"""

from collections import deque

import pytest

from cfnlint.jsonschema import CfnTemplateValidator, ValidationError
from cfnlint.rules.resources.certificatemanager.DomainValidationOptions import (
    DomainValidationOptions,
)
from cfnlint.template import Template


@pytest.fixture(scope="module")
def rule():
    rule = DomainValidationOptions()
    yield rule


@pytest.fixture(scope="module")
def validator():
    yield CfnTemplateValidator(schema={}).evolve(cfn=Template("", {}))


@pytest.mark.parametrize(
    "instance,expected",
    [
        (
            {
                "DomainName": "foo.bar",
                "ValidationDomain": "bar",
            },
            [],
        ),
        (
            [],  # wrong type
            [],
        ),
        (
            {
                "DomainName": "foo.bar",
                "ValidationDomain": "foo.bar",
            },
            [],
        ),
        (
            {
                "DomainName": "foo.bar",
                "ValidationDomain": {"Ref": "pValidationDomain"},
            },
            [],
        ),
        (
            {
                "DomainName": {"Ref": "pDomainName"},
                "ValidationDomain": "bar",
            },
            [],
        ),
        (
            {
                "DomainName": "foobar",
                "ValidationDomain": "bar",
            },
            [
                ValidationError(
                    "'bar' must be a superdomain of 'foobar'",
                    path=deque(["DomainName"]),
                )
            ],
        ),
        (
            {
                "DomainName": "foo.foo",
                "ValidationDomain": "bar",
            },
            [
                ValidationError(
                    "'bar' must be a superdomain of 'foo.foo'",
                    path=deque(["DomainName"]),
                )
            ],
        ),
    ],
)
def test_validate(instance, expected, rule, validator):
    errs = list(rule.validate(validator, "", instance, {}))

    assert errs == expected, f"Expected {expected} got {errs}"

==> cfn_lint-1.3.7.tar.gz: cfn_lint-1.3.7/test/unit/rules/resources/certificatemanager/test_domainvalidationoptions.py <==
"""
Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
SPDX-License-Identifier: MIT-0
"""

from collections import deque

import pytest

from cfnlint.jsonschema import ValidationError
from cfnlint.rules.resources.certificatemanager.DomainValidationOptions import (
    DomainValidationOptions,
)


@pytest.fixture(scope="module")
def rule():
    rule = DomainValidationOptions()
    yield rule


@pytest.mark.parametrize(
    "instance,expected",
    [
        (
            {
                "DomainName": "foo.bar",
                "ValidationDomain": "bar",
            },
            [],
        ),
        (
            [],  # wrong type
            [],
        ),
        (
            {
                "DomainName": "foo.bar",
                "ValidationDomain": "foo.bar",
            },
            [],
        ),
        (
            {
                "DomainName": "foo.bar",
                "ValidationDomain": {"Ref": "pValidationDomain"},
            },
            [],
        ),
        (
            {
                "DomainName": {"Ref": "pDomainName"},
                "ValidationDomain": "bar",
            },
            [],
        ),
        (
            {
                "DomainName": "foobar",
                "ValidationDomain": "bar",
            },
            [
                ValidationError(
                    "'bar' must be a superdomain of 'foobar'",
                    path=deque(["DomainName"]),
                )
            ],
        ),
        (
            {
                "DomainName": "foo.foo",
                "ValidationDomain": "bar",
            },
            [
                ValidationError(
                    "'bar' must be a superdomain of 'foo.foo'",
                    path=deque(["DomainName"]),
                )
            ],
        ),
    ],
)
def test_validate(instance, expected, rule, validator):
    errs = list(rule.validate(validator, "", instance, {}))

    assert errs == expected, f"Expected {expected} got {errs}"
